@@ -26,7 +26,7 @@ int notcurses_inputready_fd(struct notcurses* n);
 typedef struct cell {
   uint32_t gcluster;          // 4B → 4B
   uint8_t gcluster_backstop;  // 1B → 5B (8 bits of zero)
-  uint8_t reserved;           // 1B → 6B (8 reserved bits, ought be zero)
+  uint8_t width;              // 1B → 6B (8 bits, width biased-1)
   uint16_t stylemask;         // 2B → 8B (16 bits of NCSTYLE_* attributes)
   uint64_t channels;          // + 8b == 16b
 } cell;
@@ -53,6 +53,8 @@ void notcurses_version_components(int* major, int* minor, int* patch, int* tweak
 int notcurses_lex_margins(const char* op, notcurses_options* opts);
 int notcurses_stop(struct notcurses*);
 int notcurses_render(struct notcurses* nc);
+int ncpile_render(struct ncplane* n);
+int ncpile_rasterize(struct ncplane* n);
 int notcurses_render_to_buffer(struct notcurses* nc, char** buf, size_t* buflen);
 int notcurses_render_to_file(struct notcurses* nc, FILE* fp);
 struct ncplane* notcurses_stdplane(struct notcurses*);
@@ -151,23 +153,24 @@ void ncplane_set_styles(struct ncplane* n, unsigned stylebits);
 void ncplane_on_styles(struct ncplane* n, unsigned stylebits);
 void ncplane_off_styles(struct ncplane* n, unsigned stylebits);
 typedef struct ncstats {
-  uint64_t renders;          // number of successful notcurses_render() runs
-  uint64_t failed_renders;   // number of aborted renders, should be 0
-  uint64_t render_bytes;     // bytes emitted to ttyfp
-  int64_t render_max_bytes;  // max bytes emitted for a frame
-  int64_t render_min_bytes;  // min bytes emitted for a frame
-  uint64_t render_ns;        // nanoseconds spent in notcurses_render()
-  int64_t render_max_ns;     // max ns spent in notcurses_render()
-  int64_t render_min_ns;     // min ns spent in successful notcurses_render()
-  uint64_t cellelisions;     // cells we elided entirely thanks to damage maps
-  uint64_t cellemissions;    // cells we emitted due to inferred damage
-  uint64_t fbbytes;          // total bytes devoted to all active framebuffers
-  uint64_t fgelisions;       // RGB fg elision count
-  uint64_t fgemissions;      // RGB fg emissions
-  uint64_t bgelisions;       // RGB bg elision count
-  uint64_t bgemissions;      // RGB bg emissions
-  uint64_t defaultelisions;  // default color was emitted
-  uint64_t defaultemissions; // default color was elided
+  uint64_t renders;
+  uint64_t failed_renders;
+  uint64_t render_bytes;
+  int64_t render_max_bytes;
+  int64_t render_min_bytes;
+  uint64_t render_ns;
+  int64_t render_max_ns;
+  int64_t render_min_ns;
+  uint64_t cellelisions;
+  uint64_t cellemissions;
+  uint64_t fbbytes;
+  uint64_t fgelisions;
+  uint64_t fgemissions;
+  uint64_t bgelisions;
+  uint64_t bgemissions;
+  uint64_t defaultelisions;
+  uint64_t defaultemissions;
+  uint64_t refreshes;
 } ncstats;
 ncstats* notcurses_stats_alloc(struct notcurses* nc);
 void notcurses_stats(struct notcurses* nc, ncstats* stats);
